# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .acl import *
from .bonded_network import *
from .cloud_config import *
from .get_cloud_config import *
from .get_host import *
from .get_hosts import *
from .get_network import *
from .get_pif import *
from .get_pool import *
from .get_resource_set import *
from .get_sr import *
from .get_template import *
from .get_user import *
from .get_vdi import *
from .get_vms import *
from .get_xoa_cloud_config import *
from .get_xoa_host import *
from .get_xoa_hosts import *
from .get_xoa_network import *
from .get_xoa_pif import *
from .get_xoa_pool import *
from .get_xoa_resource_set import *
from .get_xoa_storage_repository import *
from .get_xoa_template import *
from .get_xoa_user import *
from .get_xoa_vdi import *
from .get_xoa_vms import *
from .network import *
from .provider import *
from .resource_set import *
from .vdi import *
from .vm import *
from .xoa_bonded_network import *
from .xoa_network import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_xenorchestra.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_xenorchestra.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "xenorchestra",
  "mod": "index/acl",
  "fqn": "pulumi_xenorchestra",
  "classes": {
   "xenorchestra:index/acl:Acl": "Acl"
  }
 },
 {
  "pkg": "xenorchestra",
  "mod": "index/bondedNetwork",
  "fqn": "pulumi_xenorchestra",
  "classes": {
   "xenorchestra:index/bondedNetwork:BondedNetwork": "BondedNetwork"
  }
 },
 {
  "pkg": "xenorchestra",
  "mod": "index/cloudConfig",
  "fqn": "pulumi_xenorchestra",
  "classes": {
   "xenorchestra:index/cloudConfig:CloudConfig": "CloudConfig"
  }
 },
 {
  "pkg": "xenorchestra",
  "mod": "index/network",
  "fqn": "pulumi_xenorchestra",
  "classes": {
   "xenorchestra:index/network:Network": "Network"
  }
 },
 {
  "pkg": "xenorchestra",
  "mod": "index/resourceSet",
  "fqn": "pulumi_xenorchestra",
  "classes": {
   "xenorchestra:index/resourceSet:ResourceSet": "ResourceSet"
  }
 },
 {
  "pkg": "xenorchestra",
  "mod": "index/vdi",
  "fqn": "pulumi_xenorchestra",
  "classes": {
   "xenorchestra:index/vdi:Vdi": "Vdi"
  }
 },
 {
  "pkg": "xenorchestra",
  "mod": "index/vm",
  "fqn": "pulumi_xenorchestra",
  "classes": {
   "xenorchestra:index/vm:Vm": "Vm"
  }
 },
 {
  "pkg": "xenorchestra",
  "mod": "index/xoaBondedNetwork",
  "fqn": "pulumi_xenorchestra",
  "classes": {
   "xenorchestra:index/xoaBondedNetwork:XoaBondedNetwork": "XoaBondedNetwork"
  }
 },
 {
  "pkg": "xenorchestra",
  "mod": "index/xoaNetwork",
  "fqn": "pulumi_xenorchestra",
  "classes": {
   "xenorchestra:index/xoaNetwork:XoaNetwork": "XoaNetwork"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "xenorchestra",
  "token": "pulumi:providers:xenorchestra",
  "fqn": "pulumi_xenorchestra",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetXoaNetworkResult',
    'AwaitableGetXoaNetworkResult',
    'get_xoa_network',
    'get_xoa_network_output',
]

@pulumi.output_type
class GetXoaNetworkResult:
    """
    A collection of values returned by getXoaNetwork.
    """
    def __init__(__self__, bridge=None, id=None, name_label=None, pool_id=None):
        if bridge and not isinstance(bridge, str):
            raise TypeError("Expected argument 'bridge' to be a str")
        pulumi.set(__self__, "bridge", bridge)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name_label and not isinstance(name_label, str):
            raise TypeError("Expected argument 'name_label' to be a str")
        pulumi.set(__self__, "name_label", name_label)
        if pool_id and not isinstance(pool_id, str):
            raise TypeError("Expected argument 'pool_id' to be a str")
        pulumi.set(__self__, "pool_id", pool_id)

    @property
    @pulumi.getter
    def bridge(self) -> str:
        """
        The name of the bridge network interface.
        """
        return pulumi.get(self, "bridge")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="nameLabel")
    def name_label(self) -> str:
        """
        The name of the network.
        """
        return pulumi.get(self, "name_label")

    @property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> Optional[str]:
        """
        The pool the network is associated with.
        """
        return pulumi.get(self, "pool_id")


class AwaitableGetXoaNetworkResult(GetXoaNetworkResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetXoaNetworkResult(
            bridge=self.bridge,
            id=self.id,
            name_label=self.name_label,
            pool_id=self.pool_id)


def get_xoa_network(bridge: Optional[str] = None,
                    name_label: Optional[str] = None,
                    pool_id: Optional[str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetXoaNetworkResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_xenorchestra as xenorchestra

    net = xenorchestra.get_xoa_network(name_label="Pool-wide network associated with eth0")
    demo_vm = xenorchestra.Vm("demo-vm", networks=[{
        "network_id": net.id,
    }])
    ```


    :param str bridge: The name of the bridge network interface.
    :param str name_label: The name of the network.
    :param str pool_id: The pool the network is associated with.
    """
    __args__ = dict()
    __args__['bridge'] = bridge
    __args__['nameLabel'] = name_label
    __args__['poolId'] = pool_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('xenorchestra:index/getXoaNetwork:getXoaNetwork', __args__, opts=opts, typ=GetXoaNetworkResult).value

    return AwaitableGetXoaNetworkResult(
        bridge=pulumi.get(__ret__, 'bridge'),
        id=pulumi.get(__ret__, 'id'),
        name_label=pulumi.get(__ret__, 'name_label'),
        pool_id=pulumi.get(__ret__, 'pool_id'))
def get_xoa_network_output(bridge: Optional[pulumi.Input[Optional[str]]] = None,
                           name_label: Optional[pulumi.Input[str]] = None,
                           pool_id: Optional[pulumi.Input[Optional[str]]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetXoaNetworkResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_xenorchestra as xenorchestra

    net = xenorchestra.get_xoa_network(name_label="Pool-wide network associated with eth0")
    demo_vm = xenorchestra.Vm("demo-vm", networks=[{
        "network_id": net.id,
    }])
    ```


    :param str bridge: The name of the bridge network interface.
    :param str name_label: The name of the network.
    :param str pool_id: The pool the network is associated with.
    """
    __args__ = dict()
    __args__['bridge'] = bridge
    __args__['nameLabel'] = name_label
    __args__['poolId'] = pool_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('xenorchestra:index/getXoaNetwork:getXoaNetwork', __args__, opts=opts, typ=GetXoaNetworkResult)
    return __ret__.apply(lambda __response__: GetXoaNetworkResult(
        bridge=pulumi.get(__response__, 'bridge'),
        id=pulumi.get(__response__, 'id'),
        name_label=pulumi.get(__response__, 'name_label'),
        pool_id=pulumi.get(__response__, 'pool_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ResourceSetArgs', 'ResourceSet']

@pulumi.input_type
class ResourceSetArgs:
    def __init__(__self__, *,
                 limits: pulumi.Input[Sequence[pulumi.Input['ResourceSetLimitArgs']]],
                 name: Optional[pulumi.Input[str]] = None,
                 objects: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 subjects: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a ResourceSet resource.
        :param pulumi.Input[Sequence[pulumi.Input['ResourceSetLimitArgs']]] limits: The limit applied to the resource set.
        :param pulumi.Input[str] name: The name of the resource set.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] objects: The uuids of the objects that are within scope of the resource set. A minimum of a storage repository, network and VM template are required for users to launch VMs.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] subjects: The uuids of the user accounts that should have access to the resource set.
        """
        pulumi.set(__self__, "limits", limits)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if objects is not None:
            pulumi.set(__self__, "objects", objects)
        if subjects is not None:
            pulumi.set(__self__, "subjects", subjects)

    @property
    @pulumi.getter
    def limits(self) -> pulumi.Input[Sequence[pulumi.Input['ResourceSetLimitArgs']]]:
        """
        The limit applied to the resource set.
        """
        return pulumi.get(self, "limits")

    @limits.setter
    def limits(self, value: pulumi.Input[Sequence[pulumi.Input['ResourceSetLimitArgs']]]):
        pulumi.set(self, "limits", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the resource set.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def objects(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The uuids of the objects that are within scope of the resource set. A minimum of a storage repository, network and VM template are required for users to launch VMs.
        """
        return pulumi.get(self, "objects")

    @objects.setter
    def objects(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "objects", value)

    @property
    @pulumi.getter
    def subjects(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The uuids of the user accounts that should have access to the resource set.
        """
        return pulumi.get(self, "subjects")

    @subjects.setter
    def subjects(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "subjects", value)


@pulumi.input_type
class _ResourceSetState:
    def __init__(__self__, *,
                 limits: Optional[pulumi.Input[Sequence[pulumi.Input['ResourceSetLimitArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 objects: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 subjects: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering ResourceSet resources.
        :param pulumi.Input[Sequence[pulumi.Input['ResourceSetLimitArgs']]] limits: The limit applied to the resource set.
        :param pulumi.Input[str] name: The name of the resource set.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] objects: The uuids of the objects that are within scope of the resource set. A minimum of a storage repository, network and VM template are required for users to launch VMs.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] subjects: The uuids of the user accounts that should have access to the resource set.
        """
        if limits is not None:
            pulumi.set(__self__, "limits", limits)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if objects is not None:
            pulumi.set(__self__, "objects", objects)
        if subjects is not None:
            pulumi.set(__self__, "subjects", subjects)

    @property
    @pulumi.getter
    def limits(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ResourceSetLimitArgs']]]]:
        """
        The limit applied to the resource set.
        """
        return pulumi.get(self, "limits")

    @limits.setter
    def limits(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ResourceSetLimitArgs']]]]):
        pulumi.set(self, "limits", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the resource set.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def objects(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The uuids of the objects that are within scope of the resource set. A minimum of a storage repository, network and VM template are required for users to launch VMs.
        """
        return pulumi.get(self, "objects")

    @objects.setter
    def objects(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "objects", value)

    @property
    @pulumi.getter
    def subjects(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The uuids of the user accounts that should have access to the resource set.
        """
        return pulumi.get(self, "subjects")

    @subjects.setter
    def subjects(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "subjects", value)


class ResourceSet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 limits: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ResourceSetLimitArgs', 'ResourceSetLimitArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 objects: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 subjects: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Creates a Xen Orchestra resource set.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_xenorchestra as xenorchestra

        template = xenorchestra.get_xoa_template(name_label="Ubuntu Bionic Beaver 18.04")
        sr = xenorchestra.get_xoa_storage_repository(name_label="Your storage repository label")
        eth0 = xenorchestra.get_xoa_pif(device="eth0",
            vlan=-1)
        user = xenorchestra.get_xoa_user(username="test_user")
        rs = xenorchestra.ResourceSet("rs",
            name="new-resource-set",
            subjects=[user.id],
            objects=[
                template.id,
                sr.id,
                eth0.network,
            ],
            limits=[
                {
                    "type": "cpus",
                    "quantity": 20,
                },
                {
                    "type": "disk",
                    "quantity": 107374182400,
                },
                {
                    "type": "memory",
                    "quantity": 12884901888,
                },
            ])
        ```

        ## Import

        ID can be found from the following command:

        $ xo-cli resourceSet.getAll

        ```sh
        $ pulumi import xenorchestra:index/resourceSet:ResourceSet rs MGSpuwnbtUE
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ResourceSetLimitArgs', 'ResourceSetLimitArgsDict']]]] limits: The limit applied to the resource set.
        :param pulumi.Input[str] name: The name of the resource set.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] objects: The uuids of the objects that are within scope of the resource set. A minimum of a storage repository, network and VM template are required for users to launch VMs.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] subjects: The uuids of the user accounts that should have access to the resource set.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ResourceSetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a Xen Orchestra resource set.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_xenorchestra as xenorchestra

        template = xenorchestra.get_xoa_template(name_label="Ubuntu Bionic Beaver 18.04")
        sr = xenorchestra.get_xoa_storage_repository(name_label="Your storage repository label")
        eth0 = xenorchestra.get_xoa_pif(device="eth0",
            vlan=-1)
        user = xenorchestra.get_xoa_user(username="test_user")
        rs = xenorchestra.ResourceSet("rs",
            name="new-resource-set",
            subjects=[user.id],
            objects=[
                template.id,
                sr.id,
                eth0.network,
            ],
            limits=[
                {
                    "type": "cpus",
                    "quantity": 20,
                },
                {
                    "type": "disk",
                    "quantity": 107374182400,
                },
                {
                    "type": "memory",
                    "quantity": 12884901888,
                },
            ])
        ```

        ## Import

        ID can be found from the following command:

        $ xo-cli resourceSet.getAll

        ```sh
        $ pulumi import xenorchestra:index/resourceSet:ResourceSet rs MGSpuwnbtUE
        ```

        :param str resource_name: The name of the resource.
        :param ResourceSetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ResourceSetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 limits: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ResourceSetLimitArgs', 'ResourceSetLimitArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 objects: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 subjects: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ResourceSetArgs.__new__(ResourceSetArgs)

            if limits is None and not opts.urn:
                raise TypeError("Missing required property 'limits'")
            __props__.__dict__["limits"] = limits
            __props__.__dict__["name"] = name
            __props__.__dict__["objects"] = objects
            __props__.__dict__["subjects"] = subjects
        super(ResourceSet, __self__).__init__(
            'xenorchestra:index/resourceSet:ResourceSet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            limits: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ResourceSetLimitArgs', 'ResourceSetLimitArgsDict']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            objects: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            subjects: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'ResourceSet':
        """
        Get an existing ResourceSet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ResourceSetLimitArgs', 'ResourceSetLimitArgsDict']]]] limits: The limit applied to the resource set.
        :param pulumi.Input[str] name: The name of the resource set.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] objects: The uuids of the objects that are within scope of the resource set. A minimum of a storage repository, network and VM template are required for users to launch VMs.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] subjects: The uuids of the user accounts that should have access to the resource set.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ResourceSetState.__new__(_ResourceSetState)

        __props__.__dict__["limits"] = limits
        __props__.__dict__["name"] = name
        __props__.__dict__["objects"] = objects
        __props__.__dict__["subjects"] = subjects
        return ResourceSet(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def limits(self) -> pulumi.Output[Sequence['outputs.ResourceSetLimit']]:
        """
        The limit applied to the resource set.
        """
        return pulumi.get(self, "limits")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the resource set.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def objects(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The uuids of the objects that are within scope of the resource set. A minimum of a storage repository, network and VM template are required for users to launch VMs.
        """
        return pulumi.get(self, "objects")

    @property
    @pulumi.getter
    def subjects(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The uuids of the user accounts that should have access to the resource set.
        """
        return pulumi.get(self, "subjects")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['VdiArgs', 'Vdi']

@pulumi.input_type
class VdiArgs:
    def __init__(__self__, *,
                 filepath: pulumi.Input[str],
                 name_label: pulumi.Input[str],
                 sr_id: pulumi.Input[str],
                 type: pulumi.Input[str]):
        """
        The set of arguments for constructing a Vdi resource.
        :param pulumi.Input[str] filepath: The file path to the ISO or vdi image that should be uploaded when the VDI is created.
        :param pulumi.Input[str] name_label: The name label of the VDI
        :param pulumi.Input[str] sr_id: The id of the storage repository the VDI should be created in. Make sure the storage repository supports the file you are uploading! For example, ISOs should only be uploaded to ISO storage repositories.
        :param pulumi.Input[str] type: Only `raw` uploads are supported today, but vhd support may be added in the future.
        """
        pulumi.set(__self__, "filepath", filepath)
        pulumi.set(__self__, "name_label", name_label)
        pulumi.set(__self__, "sr_id", sr_id)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def filepath(self) -> pulumi.Input[str]:
        """
        The file path to the ISO or vdi image that should be uploaded when the VDI is created.
        """
        return pulumi.get(self, "filepath")

    @filepath.setter
    def filepath(self, value: pulumi.Input[str]):
        pulumi.set(self, "filepath", value)

    @property
    @pulumi.getter(name="nameLabel")
    def name_label(self) -> pulumi.Input[str]:
        """
        The name label of the VDI
        """
        return pulumi.get(self, "name_label")

    @name_label.setter
    def name_label(self, value: pulumi.Input[str]):
        pulumi.set(self, "name_label", value)

    @property
    @pulumi.getter(name="srId")
    def sr_id(self) -> pulumi.Input[str]:
        """
        The id of the storage repository the VDI should be created in. Make sure the storage repository supports the file you are uploading! For example, ISOs should only be uploaded to ISO storage repositories.
        """
        return pulumi.get(self, "sr_id")

    @sr_id.setter
    def sr_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "sr_id", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        Only `raw` uploads are supported today, but vhd support may be added in the future.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class _VdiState:
    def __init__(__self__, *,
                 filepath: Optional[pulumi.Input[str]] = None,
                 name_label: Optional[pulumi.Input[str]] = None,
                 sr_id: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Vdi resources.
        :param pulumi.Input[str] filepath: The file path to the ISO or vdi image that should be uploaded when the VDI is created.
        :param pulumi.Input[str] name_label: The name label of the VDI
        :param pulumi.Input[str] sr_id: The id of the storage repository the VDI should be created in. Make sure the storage repository supports the file you are uploading! For example, ISOs should only be uploaded to ISO storage repositories.
        :param pulumi.Input[str] type: Only `raw` uploads are supported today, but vhd support may be added in the future.
        """
        if filepath is not None:
            pulumi.set(__self__, "filepath", filepath)
        if name_label is not None:
            pulumi.set(__self__, "name_label", name_label)
        if sr_id is not None:
            pulumi.set(__self__, "sr_id", sr_id)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def filepath(self) -> Optional[pulumi.Input[str]]:
        """
        The file path to the ISO or vdi image that should be uploaded when the VDI is created.
        """
        return pulumi.get(self, "filepath")

    @filepath.setter
    def filepath(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "filepath", value)

    @property
    @pulumi.getter(name="nameLabel")
    def name_label(self) -> Optional[pulumi.Input[str]]:
        """
        The name label of the VDI
        """
        return pulumi.get(self, "name_label")

    @name_label.setter
    def name_label(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name_label", value)

    @property
    @pulumi.getter(name="srId")
    def sr_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the storage repository the VDI should be created in. Make sure the storage repository supports the file you are uploading! For example, ISOs should only be uploaded to ISO storage repositories.
        """
        return pulumi.get(self, "sr_id")

    @sr_id.setter
    def sr_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sr_id", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        Only `raw` uploads are supported today, but vhd support may be added in the future.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


class Vdi(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 filepath: Optional[pulumi.Input[str]] = None,
                 name_label: Optional[pulumi.Input[str]] = None,
                 sr_id: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Creates a Xen Orchestra vdi resource.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] filepath: The file path to the ISO or vdi image that should be uploaded when the VDI is created.
        :param pulumi.Input[str] name_label: The name label of the VDI
        :param pulumi.Input[str] sr_id: The id of the storage repository the VDI should be created in. Make sure the storage repository supports the file you are uploading! For example, ISOs should only be uploaded to ISO storage repositories.
        :param pulumi.Input[str] type: Only `raw` uploads are supported today, but vhd support may be added in the future.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VdiArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a Xen Orchestra vdi resource.

        :param str resource_name: The name of the resource.
        :param VdiArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VdiArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 filepath: Optional[pulumi.Input[str]] = None,
                 name_label: Optional[pulumi.Input[str]] = None,
                 sr_id: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VdiArgs.__new__(VdiArgs)

            if filepath is None and not opts.urn:
                raise TypeError("Missing required property 'filepath'")
            __props__.__dict__["filepath"] = filepath
            if name_label is None and not opts.urn:
                raise TypeError("Missing required property 'name_label'")
            __props__.__dict__["name_label"] = name_label
            if sr_id is None and not opts.urn:
                raise TypeError("Missing required property 'sr_id'")
            __props__.__dict__["sr_id"] = sr_id
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
        super(Vdi, __self__).__init__(
            'xenorchestra:index/vdi:Vdi',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            filepath: Optional[pulumi.Input[str]] = None,
            name_label: Optional[pulumi.Input[str]] = None,
            sr_id: Optional[pulumi.Input[str]] = None,
            type: Optional[pulumi.Input[str]] = None) -> 'Vdi':
        """
        Get an existing Vdi resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] filepath: The file path to the ISO or vdi image that should be uploaded when the VDI is created.
        :param pulumi.Input[str] name_label: The name label of the VDI
        :param pulumi.Input[str] sr_id: The id of the storage repository the VDI should be created in. Make sure the storage repository supports the file you are uploading! For example, ISOs should only be uploaded to ISO storage repositories.
        :param pulumi.Input[str] type: Only `raw` uploads are supported today, but vhd support may be added in the future.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VdiState.__new__(_VdiState)

        __props__.__dict__["filepath"] = filepath
        __props__.__dict__["name_label"] = name_label
        __props__.__dict__["sr_id"] = sr_id
        __props__.__dict__["type"] = type
        return Vdi(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def filepath(self) -> pulumi.Output[str]:
        """
        The file path to the ISO or vdi image that should be uploaded when the VDI is created.
        """
        return pulumi.get(self, "filepath")

    @property
    @pulumi.getter(name="nameLabel")
    def name_label(self) -> pulumi.Output[str]:
        """
        The name label of the VDI
        """
        return pulumi.get(self, "name_label")

    @property
    @pulumi.getter(name="srId")
    def sr_id(self) -> pulumi.Output[str]:
        """
        The id of the storage repository the VDI should be created in. Make sure the storage repository supports the file you are uploading! For example, ISOs should only be uploaded to ISO storage repositories.
        """
        return pulumi.get(self, "sr_id")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        Only `raw` uploads are supported today, but vhd support may be added in the future.
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetXoaHostResult',
    'AwaitableGetXoaHostResult',
    'get_xoa_host',
    'get_xoa_host_output',
]

@pulumi.output_type
class GetXoaHostResult:
    """
    A collection of values returned by getXoaHost.
    """
    def __init__(__self__, cpus=None, id=None, memory=None, memory_usage=None, name_label=None, pool_id=None, tags=None):
        if cpus and not isinstance(cpus, dict):
            raise TypeError("Expected argument 'cpus' to be a dict")
        pulumi.set(__self__, "cpus", cpus)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if memory and not isinstance(memory, int):
            raise TypeError("Expected argument 'memory' to be a int")
        pulumi.set(__self__, "memory", memory)
        if memory_usage and not isinstance(memory_usage, int):
            raise TypeError("Expected argument 'memory_usage' to be a int")
        pulumi.set(__self__, "memory_usage", memory_usage)
        if name_label and not isinstance(name_label, str):
            raise TypeError("Expected argument 'name_label' to be a str")
        pulumi.set(__self__, "name_label", name_label)
        if pool_id and not isinstance(pool_id, str):
            raise TypeError("Expected argument 'pool_id' to be a str")
        pulumi.set(__self__, "pool_id", pool_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def cpus(self) -> Mapping[str, int]:
        """
        CPU information about the host. The 'cores' key will contain the number of cpu cores and the 'sockets' key will contain the number of sockets.
        """
        return pulumi.get(self, "cpus")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def memory(self) -> int:
        """
        The memory size of the host.
        """
        return pulumi.get(self, "memory")

    @property
    @pulumi.getter(name="memoryUsage")
    def memory_usage(self) -> int:
        """
        The memory usage of the host.
        """
        return pulumi.get(self, "memory_usage")

    @property
    @pulumi.getter(name="nameLabel")
    def name_label(self) -> str:
        """
        The name label of the host.
        """
        return pulumi.get(self, "name_label")

    @property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> str:
        """
        Id of the pool that the host belongs to.
        """
        return pulumi.get(self, "pool_id")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Sequence[str]]:
        """
        The tags (labels) applied to the given entity.
        """
        return pulumi.get(self, "tags")


class AwaitableGetXoaHostResult(GetXoaHostResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetXoaHostResult(
            cpus=self.cpus,
            id=self.id,
            memory=self.memory,
            memory_usage=self.memory_usage,
            name_label=self.name_label,
            pool_id=self.pool_id,
            tags=self.tags)


def get_xoa_host(name_label: Optional[str] = None,
                 tags: Optional[Sequence[str]] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetXoaHostResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_xenorchestra as xenorchestra

    host1 = xenorchestra.get_xoa_host(name_label="Your host")
    node = xenorchestra.Vm("node", affinity_host=host1.id)
    ```


    :param str name_label: The name label of the host.
    :param Sequence[str] tags: The tags (labels) applied to the given entity.
    """
    __args__ = dict()
    __args__['nameLabel'] = name_label
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('xenorchestra:index/getXoaHost:getXoaHost', __args__, opts=opts, typ=GetXoaHostResult).value

    return AwaitableGetXoaHostResult(
        cpus=pulumi.get(__ret__, 'cpus'),
        id=pulumi.get(__ret__, 'id'),
        memory=pulumi.get(__ret__, 'memory'),
        memory_usage=pulumi.get(__ret__, 'memory_usage'),
        name_label=pulumi.get(__ret__, 'name_label'),
        pool_id=pulumi.get(__ret__, 'pool_id'),
        tags=pulumi.get(__ret__, 'tags'))
def get_xoa_host_output(name_label: Optional[pulumi.Input[str]] = None,
                        tags: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetXoaHostResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_xenorchestra as xenorchestra

    host1 = xenorchestra.get_xoa_host(name_label="Your host")
    node = xenorchestra.Vm("node", affinity_host=host1.id)
    ```


    :param str name_label: The name label of the host.
    :param Sequence[str] tags: The tags (labels) applied to the given entity.
    """
    __args__ = dict()
    __args__['nameLabel'] = name_label
    __args__['tags'] = tags
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('xenorchestra:index/getXoaHost:getXoaHost', __args__, opts=opts, typ=GetXoaHostResult)
    return __ret__.apply(lambda __response__: GetXoaHostResult(
        cpus=pulumi.get(__response__, 'cpus'),
        id=pulumi.get(__response__, 'id'),
        memory=pulumi.get(__response__, 'memory'),
        memory_usage=pulumi.get(__response__, 'memory_usage'),
        name_label=pulumi.get(__response__, 'name_label'),
        pool_id=pulumi.get(__response__, 'pool_id'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetVdiResult',
    'AwaitableGetVdiResult',
    'get_vdi',
    'get_vdi_output',
]

warnings.warn("""xenorchestra.index/getvdi.getVdi has been deprecated in favor of xenorchestra.index/getxoavdi.getXoaVdi""", DeprecationWarning)

@pulumi.output_type
class GetVdiResult:
    """
    A collection of values returned by getVdi.
    """
    def __init__(__self__, id=None, name_label=None, parent=None, pool_id=None, tags=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name_label and not isinstance(name_label, str):
            raise TypeError("Expected argument 'name_label' to be a str")
        pulumi.set(__self__, "name_label", name_label)
        if parent and not isinstance(parent, str):
            raise TypeError("Expected argument 'parent' to be a str")
        pulumi.set(__self__, "parent", parent)
        if pool_id and not isinstance(pool_id, str):
            raise TypeError("Expected argument 'pool_id' to be a str")
        pulumi.set(__self__, "pool_id", pool_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the VDI.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="nameLabel")
    def name_label(self) -> Optional[str]:
        """
        The name of the VDI to look up.
        """
        return pulumi.get(self, "name_label")

    @property
    @pulumi.getter
    def parent(self) -> str:
        """
        The ID of the parent VDI if one exists. An example of when a VDI will have a parent is when it was created from a VM fast clone.
        """
        return pulumi.get(self, "parent")

    @property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> Optional[str]:
        """
        The ID of the pool the VDI belongs to. This is useful if you have a VDI with the same name on different pools.
        """
        return pulumi.get(self, "pool_id")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Sequence[str]]:
        """
        The tags (labels) applied to the given entity.
        """
        return pulumi.get(self, "tags")


class AwaitableGetVdiResult(GetVdiResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVdiResult(
            id=self.id,
            name_label=self.name_label,
            parent=self.parent,
            pool_id=self.pool_id,
            tags=self.tags)


def get_vdi(id: Optional[str] = None,
            name_label: Optional[str] = None,
            pool_id: Optional[str] = None,
            tags: Optional[Sequence[str]] = None,
            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVdiResult:
    """
    ## Example Usage


    :param str id: The ID of the VDI.
    :param str name_label: The name of the VDI to look up.
    :param str pool_id: The ID of the pool the VDI belongs to. This is useful if you have a VDI with the same name on different pools.
    :param Sequence[str] tags: The tags (labels) applied to the given entity.
    """
    pulumi.log.warn("""get_vdi is deprecated: xenorchestra.index/getvdi.getVdi has been deprecated in favor of xenorchestra.index/getxoavdi.getXoaVdi""")
    __args__ = dict()
    __args__['id'] = id
    __args__['nameLabel'] = name_label
    __args__['poolId'] = pool_id
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('xenorchestra:index/getVdi:getVdi', __args__, opts=opts, typ=GetVdiResult).value

    return AwaitableGetVdiResult(
        id=pulumi.get(__ret__, 'id'),
        name_label=pulumi.get(__ret__, 'name_label'),
        parent=pulumi.get(__ret__, 'parent'),
        pool_id=pulumi.get(__ret__, 'pool_id'),
        tags=pulumi.get(__ret__, 'tags'))
def get_vdi_output(id: Optional[pulumi.Input[Optional[str]]] = None,
                   name_label: Optional[pulumi.Input[Optional[str]]] = None,
                   pool_id: Optional[pulumi.Input[Optional[str]]] = None,
                   tags: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetVdiResult]:
    """
    ## Example Usage


    :param str id: The ID of the VDI.
    :param str name_label: The name of the VDI to look up.
    :param str pool_id: The ID of the pool the VDI belongs to. This is useful if you have a VDI with the same name on different pools.
    :param Sequence[str] tags: The tags (labels) applied to the given entity.
    """
    pulumi.log.warn("""get_vdi is deprecated: xenorchestra.index/getvdi.getVdi has been deprecated in favor of xenorchestra.index/getxoavdi.getXoaVdi""")
    __args__ = dict()
    __args__['id'] = id
    __args__['nameLabel'] = name_label
    __args__['poolId'] = pool_id
    __args__['tags'] = tags
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('xenorchestra:index/getVdi:getVdi', __args__, opts=opts, typ=GetVdiResult)
    return __ret__.apply(lambda __response__: GetVdiResult(
        id=pulumi.get(__response__, 'id'),
        name_label=pulumi.get(__response__, 'name_label'),
        parent=pulumi.get(__response__, 'parent'),
        pool_id=pulumi.get(__response__, 'pool_id'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetPoolResult',
    'AwaitableGetPoolResult',
    'get_pool',
    'get_pool_output',
]

warnings.warn("""xenorchestra.index/getpool.getPool has been deprecated in favor of xenorchestra.index/getxoapool.getXoaPool""", DeprecationWarning)

@pulumi.output_type
class GetPoolResult:
    """
    A collection of values returned by getPool.
    """
    def __init__(__self__, cpus=None, description=None, id=None, master=None, name_label=None):
        if cpus and not isinstance(cpus, dict):
            raise TypeError("Expected argument 'cpus' to be a dict")
        pulumi.set(__self__, "cpus", cpus)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if master and not isinstance(master, str):
            raise TypeError("Expected argument 'master' to be a str")
        pulumi.set(__self__, "master", master)
        if name_label and not isinstance(name_label, str):
            raise TypeError("Expected argument 'name_label' to be a str")
        pulumi.set(__self__, "name_label", name_label)

    @property
    @pulumi.getter
    def cpus(self) -> Mapping[str, str]:
        """
        CPU information about the pool. The 'cores' key will contain the number of cpu cores and the 'sockets' key will contain the number of sockets.
        """
        return pulumi.get(self, "cpus")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the pool.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def master(self) -> str:
        """
        The id of the primary instance in the pool.
        """
        return pulumi.get(self, "master")

    @property
    @pulumi.getter(name="nameLabel")
    def name_label(self) -> str:
        """
        The name_label of the pool to look up.
        """
        return pulumi.get(self, "name_label")


class AwaitableGetPoolResult(GetPoolResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPoolResult(
            cpus=self.cpus,
            description=self.description,
            id=self.id,
            master=self.master,
            name_label=self.name_label)


def get_pool(name_label: Optional[str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPoolResult:
    """
    Provides information about a pool.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_xenorchestra as xenorchestra

    pool = xenorchestra.get_xoa_pool(name_label="Your pool")
    local_storage = xenorchestra.get_xoa_storage_repository(name_label="Your storage repository label",
        pool_id=pool.id)
    ```


    :param str name_label: The name_label of the pool to look up.
    """
    pulumi.log.warn("""get_pool is deprecated: xenorchestra.index/getpool.getPool has been deprecated in favor of xenorchestra.index/getxoapool.getXoaPool""")
    __args__ = dict()
    __args__['nameLabel'] = name_label
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('xenorchestra:index/getPool:getPool', __args__, opts=opts, typ=GetPoolResult).value

    return AwaitableGetPoolResult(
        cpus=pulumi.get(__ret__, 'cpus'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        master=pulumi.get(__ret__, 'master'),
        name_label=pulumi.get(__ret__, 'name_label'))
def get_pool_output(name_label: Optional[pulumi.Input[str]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPoolResult]:
    """
    Provides information about a pool.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_xenorchestra as xenorchestra

    pool = xenorchestra.get_xoa_pool(name_label="Your pool")
    local_storage = xenorchestra.get_xoa_storage_repository(name_label="Your storage repository label",
        pool_id=pool.id)
    ```


    :param str name_label: The name_label of the pool to look up.
    """
    pulumi.log.warn("""get_pool is deprecated: xenorchestra.index/getpool.getPool has been deprecated in favor of xenorchestra.index/getxoapool.getXoaPool""")
    __args__ = dict()
    __args__['nameLabel'] = name_label
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('xenorchestra:index/getPool:getPool', __args__, opts=opts, typ=GetPoolResult)
    return __ret__.apply(lambda __response__: GetPoolResult(
        cpus=pulumi.get(__response__, 'cpus'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        master=pulumi.get(__response__, 'master'),
        name_label=pulumi.get(__response__, 'name_label')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('xenorchestra')


class _ExportableConfig(types.ModuleType):
    @property
    def insecure(self) -> Optional[bool]:
        """
        Whether SSL should be verified or not. Can be set via the XOA_INSECURE environment variable.
        """
        return __config__.get_bool('insecure')

    @property
    def password(self) -> Optional[str]:
        """
        Password for xoa api. Can be set via the XOA_PASSWORD environment variable.
        """
        return __config__.get('password')

    @property
    def retry_max_time(self) -> Optional[str]:
        """
        If `retry_mode` is set, this specifies the duration for which the backoff method will continue retries. Can be set via
        the `XOA_RETRY_MAX_TIME` environment variable
        """
        return __config__.get('retryMaxTime')

    @property
    def retry_mode(self) -> Optional[str]:
        """
        Specifies if retries should be attempted for requests that require eventual . Can be set via the XOA_RETRY_MODE
        environment variable.
        """
        return __config__.get('retryMode')

    @property
    def token(self) -> Optional[str]:
        """
        Password for xoa api. Can be set via the XOA_TOKEN environment variable.
        """
        return __config__.get('token')

    @property
    def url(self) -> Optional[str]:
        """
        Hostname of the xoa router. Can be set via the XOA_URL environment variable.
        """
        return __config__.get('url')

    @property
    def username(self) -> Optional[str]:
        """
        User account for xoa api. Can be set via the XOA_USER environment variable.
        """
        return __config__.get('username')




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetCloudConfigResult',
    'AwaitableGetCloudConfigResult',
    'get_cloud_config',
    'get_cloud_config_output',
]

warnings.warn("""xenorchestra.index/getcloudconfig.getCloudConfig has been deprecated in favor of xenorchestra.index/getxoacloudconfig.getXoaCloudConfig""", DeprecationWarning)

@pulumi.output_type
class GetCloudConfigResult:
    """
    A collection of values returned by getCloudConfig.
    """
    def __init__(__self__, id=None, name=None, template=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if template and not isinstance(template, str):
            raise TypeError("Expected argument 'template' to be a str")
        pulumi.set(__self__, "template", template)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the cloud config you want to look up.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def template(self) -> str:
        """
        The contents of the cloud-config.
        """
        return pulumi.get(self, "template")


class AwaitableGetCloudConfigResult(GetCloudConfigResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCloudConfigResult(
            id=self.id,
            name=self.name,
            template=self.template)


def get_cloud_config(name: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCloudConfigResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_xenorchestra as xenorchestra

    cloud_config = xenorchestra.get_xoa_cloud_config(name="Name of cloud config")
    ```


    :param str name: The name of the cloud config you want to look up.
    """
    pulumi.log.warn("""get_cloud_config is deprecated: xenorchestra.index/getcloudconfig.getCloudConfig has been deprecated in favor of xenorchestra.index/getxoacloudconfig.getXoaCloudConfig""")
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('xenorchestra:index/getCloudConfig:getCloudConfig', __args__, opts=opts, typ=GetCloudConfigResult).value

    return AwaitableGetCloudConfigResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        template=pulumi.get(__ret__, 'template'))
def get_cloud_config_output(name: Optional[pulumi.Input[str]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCloudConfigResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_xenorchestra as xenorchestra

    cloud_config = xenorchestra.get_xoa_cloud_config(name="Name of cloud config")
    ```


    :param str name: The name of the cloud config you want to look up.
    """
    pulumi.log.warn("""get_cloud_config is deprecated: xenorchestra.index/getcloudconfig.getCloudConfig has been deprecated in favor of xenorchestra.index/getxoacloudconfig.getXoaCloudConfig""")
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('xenorchestra:index/getCloudConfig:getCloudConfig', __args__, opts=opts, typ=GetCloudConfigResult)
    return __ret__.apply(lambda __response__: GetCloudConfigResult(
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        template=pulumi.get(__response__, 'template')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetHostsResult',
    'AwaitableGetHostsResult',
    'get_hosts',
    'get_hosts_output',
]

warnings.warn("""xenorchestra.index/gethosts.getHosts has been deprecated in favor of xenorchestra.index/getxoahosts.getXoaHosts""", DeprecationWarning)

@pulumi.output_type
class GetHostsResult:
    """
    A collection of values returned by getHosts.
    """
    def __init__(__self__, hosts=None, id=None, master=None, pool_id=None, sort_by=None, sort_order=None, tags=None):
        if hosts and not isinstance(hosts, list):
            raise TypeError("Expected argument 'hosts' to be a list")
        pulumi.set(__self__, "hosts", hosts)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if master and not isinstance(master, str):
            raise TypeError("Expected argument 'master' to be a str")
        pulumi.set(__self__, "master", master)
        if pool_id and not isinstance(pool_id, str):
            raise TypeError("Expected argument 'pool_id' to be a str")
        pulumi.set(__self__, "pool_id", pool_id)
        if sort_by and not isinstance(sort_by, str):
            raise TypeError("Expected argument 'sort_by' to be a str")
        pulumi.set(__self__, "sort_by", sort_by)
        if sort_order and not isinstance(sort_order, str):
            raise TypeError("Expected argument 'sort_order' to be a str")
        pulumi.set(__self__, "sort_order", sort_order)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def hosts(self) -> Sequence['outputs.GetHostsHostResult']:
        """
        The resulting hosts after applying the argument filtering.
        """
        return pulumi.get(self, "hosts")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def master(self) -> str:
        """
        The primary host of the pool.
        """
        return pulumi.get(self, "master")

    @property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> str:
        """
        The pool id used to filter the resulting hosts by.
        """
        return pulumi.get(self, "pool_id")

    @property
    @pulumi.getter(name="sortBy")
    def sort_by(self) -> Optional[str]:
        """
        The host field to sort the results by (id and name_label are supported).
        """
        return pulumi.get(self, "sort_by")

    @property
    @pulumi.getter(name="sortOrder")
    def sort_order(self) -> Optional[str]:
        """
        Valid options are `asc` or `desc` and sort order is applied to `sort_by` argument.
        """
        return pulumi.get(self, "sort_order")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Sequence[str]]:
        """
        The tags (labels) applied to the given entity.
        """
        return pulumi.get(self, "tags")


class AwaitableGetHostsResult(GetHostsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetHostsResult(
            hosts=self.hosts,
            id=self.id,
            master=self.master,
            pool_id=self.pool_id,
            sort_by=self.sort_by,
            sort_order=self.sort_order,
            tags=self.tags)


def get_hosts(pool_id: Optional[str] = None,
              sort_by: Optional[str] = None,
              sort_order: Optional[str] = None,
              tags: Optional[Sequence[str]] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetHostsResult:
    """
    Use this data source to filter Xenorchestra hosts by certain criteria (name_label, tags) for use in other resources.


    :param str pool_id: The pool id used to filter the resulting hosts by.
    :param str sort_by: The host field to sort the results by (id and name_label are supported).
    :param str sort_order: Valid options are `asc` or `desc` and sort order is applied to `sort_by` argument.
    :param Sequence[str] tags: The tags (labels) applied to the given entity.
    """
    pulumi.log.warn("""get_hosts is deprecated: xenorchestra.index/gethosts.getHosts has been deprecated in favor of xenorchestra.index/getxoahosts.getXoaHosts""")
    __args__ = dict()
    __args__['poolId'] = pool_id
    __args__['sortBy'] = sort_by
    __args__['sortOrder'] = sort_order
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('xenorchestra:index/getHosts:getHosts', __args__, opts=opts, typ=GetHostsResult).value

    return AwaitableGetHostsResult(
        hosts=pulumi.get(__ret__, 'hosts'),
        id=pulumi.get(__ret__, 'id'),
        master=pulumi.get(__ret__, 'master'),
        pool_id=pulumi.get(__ret__, 'pool_id'),
        sort_by=pulumi.get(__ret__, 'sort_by'),
        sort_order=pulumi.get(__ret__, 'sort_order'),
        tags=pulumi.get(__ret__, 'tags'))
def get_hosts_output(pool_id: Optional[pulumi.Input[str]] = None,
                     sort_by: Optional[pulumi.Input[Optional[str]]] = None,
                     sort_order: Optional[pulumi.Input[Optional[str]]] = None,
                     tags: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetHostsResult]:
    """
    Use this data source to filter Xenorchestra hosts by certain criteria (name_label, tags) for use in other resources.


    :param str pool_id: The pool id used to filter the resulting hosts by.
    :param str sort_by: The host field to sort the results by (id and name_label are supported).
    :param str sort_order: Valid options are `asc` or `desc` and sort order is applied to `sort_by` argument.
    :param Sequence[str] tags: The tags (labels) applied to the given entity.
    """
    pulumi.log.warn("""get_hosts is deprecated: xenorchestra.index/gethosts.getHosts has been deprecated in favor of xenorchestra.index/getxoahosts.getXoaHosts""")
    __args__ = dict()
    __args__['poolId'] = pool_id
    __args__['sortBy'] = sort_by
    __args__['sortOrder'] = sort_order
    __args__['tags'] = tags
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('xenorchestra:index/getHosts:getHosts', __args__, opts=opts, typ=GetHostsResult)
    return __ret__.apply(lambda __response__: GetHostsResult(
        hosts=pulumi.get(__response__, 'hosts'),
        id=pulumi.get(__response__, 'id'),
        master=pulumi.get(__response__, 'master'),
        pool_id=pulumi.get(__response__, 'pool_id'),
        sort_by=pulumi.get(__response__, 'sort_by'),
        sort_order=pulumi.get(__response__, 'sort_order'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetPifResult',
    'AwaitableGetPifResult',
    'get_pif',
    'get_pif_output',
]

warnings.warn("""xenorchestra.index/getpif.getPif has been deprecated in favor of xenorchestra.index/getxoapif.getXoaPif""", DeprecationWarning)

@pulumi.output_type
class GetPifResult:
    """
    A collection of values returned by getPif.
    """
    def __init__(__self__, attached=None, device=None, host=None, host_id=None, id=None, network=None, pool_id=None, uuid=None, vlan=None):
        if attached and not isinstance(attached, bool):
            raise TypeError("Expected argument 'attached' to be a bool")
        pulumi.set(__self__, "attached", attached)
        if device and not isinstance(device, str):
            raise TypeError("Expected argument 'device' to be a str")
        pulumi.set(__self__, "device", device)
        if host and not isinstance(host, str):
            raise TypeError("Expected argument 'host' to be a str")
        pulumi.set(__self__, "host", host)
        if host_id and not isinstance(host_id, str):
            raise TypeError("Expected argument 'host_id' to be a str")
        pulumi.set(__self__, "host_id", host_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if network and not isinstance(network, str):
            raise TypeError("Expected argument 'network' to be a str")
        pulumi.set(__self__, "network", network)
        if pool_id and not isinstance(pool_id, str):
            raise TypeError("Expected argument 'pool_id' to be a str")
        pulumi.set(__self__, "pool_id", pool_id)
        if uuid and not isinstance(uuid, str):
            raise TypeError("Expected argument 'uuid' to be a str")
        pulumi.set(__self__, "uuid", uuid)
        if vlan and not isinstance(vlan, int):
            raise TypeError("Expected argument 'vlan' to be a int")
        pulumi.set(__self__, "vlan", vlan)

    @property
    @pulumi.getter
    def attached(self) -> bool:
        """
        If the PIF is attached to the network.
        """
        return pulumi.get(self, "attached")

    @property
    @pulumi.getter
    def device(self) -> str:
        """
        The name of the network device. Examples include eth0, eth1, etc. See `ifconfig` for possible devices.
        """
        return pulumi.get(self, "device")

    @property
    @pulumi.getter
    def host(self) -> str:
        """
        The host the PIF is associated with.
        """
        return pulumi.get(self, "host")

    @property
    @pulumi.getter(name="hostId")
    def host_id(self) -> str:
        """
        The ID of the host that the PIF belongs to.
        """
        return pulumi.get(self, "host_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def network(self) -> str:
        """
        The network the PIF is associated with.
        """
        return pulumi.get(self, "network")

    @property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> str:
        """
        The pool the PIF is associated with.
        """
        return pulumi.get(self, "pool_id")

    @property
    @pulumi.getter
    def uuid(self) -> str:
        """
        The uuid of the PIF.
        """
        return pulumi.get(self, "uuid")

    @property
    @pulumi.getter
    def vlan(self) -> int:
        """
        The VLAN the PIF belongs to.
        """
        return pulumi.get(self, "vlan")


class AwaitableGetPifResult(GetPifResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPifResult(
            attached=self.attached,
            device=self.device,
            host=self.host,
            host_id=self.host_id,
            id=self.id,
            network=self.network,
            pool_id=self.pool_id,
            uuid=self.uuid,
            vlan=self.vlan)


def get_pif(device: Optional[str] = None,
            host_id: Optional[str] = None,
            vlan: Optional[int] = None,
            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPifResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_xenorchestra as xenorchestra

    eth0 = xenorchestra.get_xoa_pif(device="eth0",
        vlan=-1)
    demo_vm = xenorchestra.Vm("demo-vm", networks=[{
        "network_id": eth0.network,
    }])
    ```


    :param str device: The name of the network device. Examples include eth0, eth1, etc. See `ifconfig` for possible devices.
    :param str host_id: The ID of the host that the PIF belongs to.
    :param int vlan: The VLAN the PIF belongs to.
    """
    pulumi.log.warn("""get_pif is deprecated: xenorchestra.index/getpif.getPif has been deprecated in favor of xenorchestra.index/getxoapif.getXoaPif""")
    __args__ = dict()
    __args__['device'] = device
    __args__['hostId'] = host_id
    __args__['vlan'] = vlan
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('xenorchestra:index/getPif:getPif', __args__, opts=opts, typ=GetPifResult).value

    return AwaitableGetPifResult(
        attached=pulumi.get(__ret__, 'attached'),
        device=pulumi.get(__ret__, 'device'),
        host=pulumi.get(__ret__, 'host'),
        host_id=pulumi.get(__ret__, 'host_id'),
        id=pulumi.get(__ret__, 'id'),
        network=pulumi.get(__ret__, 'network'),
        pool_id=pulumi.get(__ret__, 'pool_id'),
        uuid=pulumi.get(__ret__, 'uuid'),
        vlan=pulumi.get(__ret__, 'vlan'))
def get_pif_output(device: Optional[pulumi.Input[str]] = None,
                   host_id: Optional[pulumi.Input[Optional[str]]] = None,
                   vlan: Optional[pulumi.Input[int]] = None,
                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPifResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_xenorchestra as xenorchestra

    eth0 = xenorchestra.get_xoa_pif(device="eth0",
        vlan=-1)
    demo_vm = xenorchestra.Vm("demo-vm", networks=[{
        "network_id": eth0.network,
    }])
    ```


    :param str device: The name of the network device. Examples include eth0, eth1, etc. See `ifconfig` for possible devices.
    :param str host_id: The ID of the host that the PIF belongs to.
    :param int vlan: The VLAN the PIF belongs to.
    """
    pulumi.log.warn("""get_pif is deprecated: xenorchestra.index/getpif.getPif has been deprecated in favor of xenorchestra.index/getxoapif.getXoaPif""")
    __args__ = dict()
    __args__['device'] = device
    __args__['hostId'] = host_id
    __args__['vlan'] = vlan
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('xenorchestra:index/getPif:getPif', __args__, opts=opts, typ=GetPifResult)
    return __ret__.apply(lambda __response__: GetPifResult(
        attached=pulumi.get(__response__, 'attached'),
        device=pulumi.get(__response__, 'device'),
        host=pulumi.get(__response__, 'host'),
        host_id=pulumi.get(__response__, 'host_id'),
        id=pulumi.get(__response__, 'id'),
        network=pulumi.get(__response__, 'network'),
        pool_id=pulumi.get(__response__, 'pool_id'),
        uuid=pulumi.get(__response__, 'uuid'),
        vlan=pulumi.get(__response__, 'vlan')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProviderArgs', 'Provider']

@pulumi.input_type
class ProviderArgs:
    def __init__(__self__, *,
                 url: pulumi.Input[str],
                 insecure: Optional[pulumi.Input[bool]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 retry_max_time: Optional[pulumi.Input[str]] = None,
                 retry_mode: Optional[pulumi.Input[str]] = None,
                 token: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Provider resource.
        :param pulumi.Input[str] url: Hostname of the xoa router. Can be set via the XOA_URL environment variable.
        :param pulumi.Input[bool] insecure: Whether SSL should be verified or not. Can be set via the XOA_INSECURE environment variable.
        :param pulumi.Input[str] password: Password for xoa api. Can be set via the XOA_PASSWORD environment variable.
        :param pulumi.Input[str] retry_max_time: If `retry_mode` is set, this specifies the duration for which the backoff method will continue retries. Can be set via
               the `XOA_RETRY_MAX_TIME` environment variable
        :param pulumi.Input[str] retry_mode: Specifies if retries should be attempted for requests that require eventual . Can be set via the XOA_RETRY_MODE
               environment variable.
        :param pulumi.Input[str] token: Password for xoa api. Can be set via the XOA_TOKEN environment variable.
        :param pulumi.Input[str] username: User account for xoa api. Can be set via the XOA_USER environment variable.
        """
        pulumi.set(__self__, "url", url)
        if insecure is not None:
            pulumi.set(__self__, "insecure", insecure)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if retry_max_time is not None:
            pulumi.set(__self__, "retry_max_time", retry_max_time)
        if retry_mode is not None:
            pulumi.set(__self__, "retry_mode", retry_mode)
        if token is not None:
            pulumi.set(__self__, "token", token)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def url(self) -> pulumi.Input[str]:
        """
        Hostname of the xoa router. Can be set via the XOA_URL environment variable.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[str]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter
    def insecure(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether SSL should be verified or not. Can be set via the XOA_INSECURE environment variable.
        """
        return pulumi.get(self, "insecure")

    @insecure.setter
    def insecure(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "insecure", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        Password for xoa api. Can be set via the XOA_PASSWORD environment variable.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="retryMaxTime")
    def retry_max_time(self) -> Optional[pulumi.Input[str]]:
        """
        If `retry_mode` is set, this specifies the duration for which the backoff method will continue retries. Can be set via
        the `XOA_RETRY_MAX_TIME` environment variable
        """
        return pulumi.get(self, "retry_max_time")

    @retry_max_time.setter
    def retry_max_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "retry_max_time", value)

    @property
    @pulumi.getter(name="retryMode")
    def retry_mode(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies if retries should be attempted for requests that require eventual . Can be set via the XOA_RETRY_MODE
        environment variable.
        """
        return pulumi.get(self, "retry_mode")

    @retry_mode.setter
    def retry_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "retry_mode", value)

    @property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[str]]:
        """
        Password for xoa api. Can be set via the XOA_TOKEN environment variable.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "token", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[str]]:
        """
        User account for xoa api. Can be set via the XOA_USER environment variable.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username", value)


class Provider(pulumi.ProviderResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 insecure: Optional[pulumi.Input[bool]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 retry_max_time: Optional[pulumi.Input[str]] = None,
                 retry_mode: Optional[pulumi.Input[str]] = None,
                 token: Optional[pulumi.Input[str]] = None,
                 url: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The provider type for the xenorchestra package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] insecure: Whether SSL should be verified or not. Can be set via the XOA_INSECURE environment variable.
        :param pulumi.Input[str] password: Password for xoa api. Can be set via the XOA_PASSWORD environment variable.
        :param pulumi.Input[str] retry_max_time: If `retry_mode` is set, this specifies the duration for which the backoff method will continue retries. Can be set via
               the `XOA_RETRY_MAX_TIME` environment variable
        :param pulumi.Input[str] retry_mode: Specifies if retries should be attempted for requests that require eventual . Can be set via the XOA_RETRY_MODE
               environment variable.
        :param pulumi.Input[str] token: Password for xoa api. Can be set via the XOA_TOKEN environment variable.
        :param pulumi.Input[str] url: Hostname of the xoa router. Can be set via the XOA_URL environment variable.
        :param pulumi.Input[str] username: User account for xoa api. Can be set via the XOA_USER environment variable.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProviderArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The provider type for the xenorchestra package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param ProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 insecure: Optional[pulumi.Input[bool]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 retry_max_time: Optional[pulumi.Input[str]] = None,
                 retry_mode: Optional[pulumi.Input[str]] = None,
                 token: Optional[pulumi.Input[str]] = None,
                 url: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderArgs.__new__(ProviderArgs)

            __props__.__dict__["insecure"] = pulumi.Output.from_input(insecure).apply(pulumi.runtime.to_json) if insecure is not None else None
            __props__.__dict__["password"] = password
            __props__.__dict__["retry_max_time"] = retry_max_time
            __props__.__dict__["retry_mode"] = retry_mode
            __props__.__dict__["token"] = token
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__.__dict__["url"] = url
            __props__.__dict__["username"] = username
        super(Provider, __self__).__init__(
            'xenorchestra',
            resource_name,
            __props__,
            opts)

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional[str]]:
        """
        Password for xoa api. Can be set via the XOA_PASSWORD environment variable.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="retryMaxTime")
    def retry_max_time(self) -> pulumi.Output[Optional[str]]:
        """
        If `retry_mode` is set, this specifies the duration for which the backoff method will continue retries. Can be set via
        the `XOA_RETRY_MAX_TIME` environment variable
        """
        return pulumi.get(self, "retry_max_time")

    @property
    @pulumi.getter(name="retryMode")
    def retry_mode(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies if retries should be attempted for requests that require eventual . Can be set via the XOA_RETRY_MODE
        environment variable.
        """
        return pulumi.get(self, "retry_mode")

    @property
    @pulumi.getter
    def token(self) -> pulumi.Output[Optional[str]]:
        """
        Password for xoa api. Can be set via the XOA_TOKEN environment variable.
        """
        return pulumi.get(self, "token")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[str]:
        """
        Hostname of the xoa router. Can be set via the XOA_URL environment variable.
        """
        return pulumi.get(self, "url")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[Optional[str]]:
        """
        User account for xoa api. Can be set via the XOA_USER environment variable.
        """
        return pulumi.get(self, "username")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['AclArgs', 'Acl']

@pulumi.input_type
class AclArgs:
    def __init__(__self__, *,
                 action: pulumi.Input[str],
                 object: pulumi.Input[str],
                 subject: pulumi.Input[str]):
        """
        The set of arguments for constructing a Acl resource.
        :param pulumi.Input[str] action: Must be one of admin, operator, viewer. See the [Xen orchestra docs](https://xen-orchestra.com/docs/acls.html) on ACLs for more details.
        :param pulumi.Input[str] object: The id of the object that will be able to be used by the subject.
        :param pulumi.Input[str] subject: The uuid of the user account that the acl will apply to.
        """
        pulumi.set(__self__, "action", action)
        pulumi.set(__self__, "object", object)
        pulumi.set(__self__, "subject", subject)

    @property
    @pulumi.getter
    def action(self) -> pulumi.Input[str]:
        """
        Must be one of admin, operator, viewer. See the [Xen orchestra docs](https://xen-orchestra.com/docs/acls.html) on ACLs for more details.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: pulumi.Input[str]):
        pulumi.set(self, "action", value)

    @property
    @pulumi.getter
    def object(self) -> pulumi.Input[str]:
        """
        The id of the object that will be able to be used by the subject.
        """
        return pulumi.get(self, "object")

    @object.setter
    def object(self, value: pulumi.Input[str]):
        pulumi.set(self, "object", value)

    @property
    @pulumi.getter
    def subject(self) -> pulumi.Input[str]:
        """
        The uuid of the user account that the acl will apply to.
        """
        return pulumi.get(self, "subject")

    @subject.setter
    def subject(self, value: pulumi.Input[str]):
        pulumi.set(self, "subject", value)


@pulumi.input_type
class _AclState:
    def __init__(__self__, *,
                 action: Optional[pulumi.Input[str]] = None,
                 object: Optional[pulumi.Input[str]] = None,
                 subject: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Acl resources.
        :param pulumi.Input[str] action: Must be one of admin, operator, viewer. See the [Xen orchestra docs](https://xen-orchestra.com/docs/acls.html) on ACLs for more details.
        :param pulumi.Input[str] object: The id of the object that will be able to be used by the subject.
        :param pulumi.Input[str] subject: The uuid of the user account that the acl will apply to.
        """
        if action is not None:
            pulumi.set(__self__, "action", action)
        if object is not None:
            pulumi.set(__self__, "object", object)
        if subject is not None:
            pulumi.set(__self__, "subject", subject)

    @property
    @pulumi.getter
    def action(self) -> Optional[pulumi.Input[str]]:
        """
        Must be one of admin, operator, viewer. See the [Xen orchestra docs](https://xen-orchestra.com/docs/acls.html) on ACLs for more details.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "action", value)

    @property
    @pulumi.getter
    def object(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the object that will be able to be used by the subject.
        """
        return pulumi.get(self, "object")

    @object.setter
    def object(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "object", value)

    @property
    @pulumi.getter
    def subject(self) -> Optional[pulumi.Input[str]]:
        """
        The uuid of the user account that the acl will apply to.
        """
        return pulumi.get(self, "subject")

    @subject.setter
    def subject(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "subject", value)


class Acl(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[str]] = None,
                 object: Optional[pulumi.Input[str]] = None,
                 subject: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_xenorchestra as xenorchestra

        pool = xenorchestra.get_xoa_pool(name_label="Your pool")
        user = xenorchestra.get_xoa_user(username="my-username")
        acl = xenorchestra.Acl("acl",
            subject=user.id,
            object=pool.id,
            action="operator")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] action: Must be one of admin, operator, viewer. See the [Xen orchestra docs](https://xen-orchestra.com/docs/acls.html) on ACLs for more details.
        :param pulumi.Input[str] object: The id of the object that will be able to be used by the subject.
        :param pulumi.Input[str] subject: The uuid of the user account that the acl will apply to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AclArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_xenorchestra as xenorchestra

        pool = xenorchestra.get_xoa_pool(name_label="Your pool")
        user = xenorchestra.get_xoa_user(username="my-username")
        acl = xenorchestra.Acl("acl",
            subject=user.id,
            object=pool.id,
            action="operator")
        ```

        :param str resource_name: The name of the resource.
        :param AclArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AclArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[str]] = None,
                 object: Optional[pulumi.Input[str]] = None,
                 subject: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AclArgs.__new__(AclArgs)

            if action is None and not opts.urn:
                raise TypeError("Missing required property 'action'")
            __props__.__dict__["action"] = action
            if object is None and not opts.urn:
                raise TypeError("Missing required property 'object'")
            __props__.__dict__["object"] = object
            if subject is None and not opts.urn:
                raise TypeError("Missing required property 'subject'")
            __props__.__dict__["subject"] = subject
        super(Acl, __self__).__init__(
            'xenorchestra:index/acl:Acl',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            action: Optional[pulumi.Input[str]] = None,
            object: Optional[pulumi.Input[str]] = None,
            subject: Optional[pulumi.Input[str]] = None) -> 'Acl':
        """
        Get an existing Acl resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] action: Must be one of admin, operator, viewer. See the [Xen orchestra docs](https://xen-orchestra.com/docs/acls.html) on ACLs for more details.
        :param pulumi.Input[str] object: The id of the object that will be able to be used by the subject.
        :param pulumi.Input[str] subject: The uuid of the user account that the acl will apply to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AclState.__new__(_AclState)

        __props__.__dict__["action"] = action
        __props__.__dict__["object"] = object
        __props__.__dict__["subject"] = subject
        return Acl(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def action(self) -> pulumi.Output[str]:
        """
        Must be one of admin, operator, viewer. See the [Xen orchestra docs](https://xen-orchestra.com/docs/acls.html) on ACLs for more details.
        """
        return pulumi.get(self, "action")

    @property
    @pulumi.getter
    def object(self) -> pulumi.Output[str]:
        """
        The id of the object that will be able to be used by the subject.
        """
        return pulumi.get(self, "object")

    @property
    @pulumi.getter
    def subject(self) -> pulumi.Output[str]:
        """
        The uuid of the user account that the acl will apply to.
        """
        return pulumi.get(self, "subject")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetXoaVmsResult',
    'AwaitableGetXoaVmsResult',
    'get_xoa_vms',
    'get_xoa_vms_output',
]

@pulumi.output_type
class GetXoaVmsResult:
    """
    A collection of values returned by getXoaVms.
    """
    def __init__(__self__, host=None, id=None, pool_id=None, power_state=None, vms=None):
        if host and not isinstance(host, str):
            raise TypeError("Expected argument 'host' to be a str")
        pulumi.set(__self__, "host", host)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if pool_id and not isinstance(pool_id, str):
            raise TypeError("Expected argument 'pool_id' to be a str")
        pulumi.set(__self__, "pool_id", pool_id)
        if power_state and not isinstance(power_state, str):
            raise TypeError("Expected argument 'power_state' to be a str")
        pulumi.set(__self__, "power_state", power_state)
        if vms and not isinstance(vms, list):
            raise TypeError("Expected argument 'vms' to be a list")
        pulumi.set(__self__, "vms", vms)

    @property
    @pulumi.getter
    def host(self) -> Optional[str]:
        return pulumi.get(self, "host")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> str:
        """
        The ID of the pool the VM belongs to.
        """
        return pulumi.get(self, "pool_id")

    @property
    @pulumi.getter(name="powerState")
    def power_state(self) -> Optional[str]:
        """
        The power state of the vms. (Running, Halted)
        """
        return pulumi.get(self, "power_state")

    @property
    @pulumi.getter
    def vms(self) -> Sequence['outputs.GetXoaVmsVmResult']:
        """
        A list of information for all vms found in this pool.
        """
        return pulumi.get(self, "vms")


class AwaitableGetXoaVmsResult(GetXoaVmsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetXoaVmsResult(
            host=self.host,
            id=self.id,
            pool_id=self.pool_id,
            power_state=self.power_state,
            vms=self.vms)


def get_xoa_vms(host: Optional[str] = None,
                pool_id: Optional[str] = None,
                power_state: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetXoaVmsResult:
    """
    Use this data source to filter Xenorchestra VMs by certain criteria (pool_id, power_state or host) for use in other resources.


    :param str pool_id: The ID of the pool the VM belongs to.
    :param str power_state: The power state of the vms. (Running, Halted)
    """
    __args__ = dict()
    __args__['host'] = host
    __args__['poolId'] = pool_id
    __args__['powerState'] = power_state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('xenorchestra:index/getXoaVms:getXoaVms', __args__, opts=opts, typ=GetXoaVmsResult).value

    return AwaitableGetXoaVmsResult(
        host=pulumi.get(__ret__, 'host'),
        id=pulumi.get(__ret__, 'id'),
        pool_id=pulumi.get(__ret__, 'pool_id'),
        power_state=pulumi.get(__ret__, 'power_state'),
        vms=pulumi.get(__ret__, 'vms'))
def get_xoa_vms_output(host: Optional[pulumi.Input[Optional[str]]] = None,
                       pool_id: Optional[pulumi.Input[str]] = None,
                       power_state: Optional[pulumi.Input[Optional[str]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetXoaVmsResult]:
    """
    Use this data source to filter Xenorchestra VMs by certain criteria (pool_id, power_state or host) for use in other resources.


    :param str pool_id: The ID of the pool the VM belongs to.
    :param str power_state: The power state of the vms. (Running, Halted)
    """
    __args__ = dict()
    __args__['host'] = host
    __args__['poolId'] = pool_id
    __args__['powerState'] = power_state
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('xenorchestra:index/getXoaVms:getXoaVms', __args__, opts=opts, typ=GetXoaVmsResult)
    return __ret__.apply(lambda __response__: GetXoaVmsResult(
        host=pulumi.get(__response__, 'host'),
        id=pulumi.get(__response__, 'id'),
        pool_id=pulumi.get(__response__, 'pool_id'),
        power_state=pulumi.get(__response__, 'power_state'),
        vms=pulumi.get(__response__, 'vms')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['XoaBondedNetworkArgs', 'XoaBondedNetwork']

@pulumi.input_type
class XoaBondedNetworkArgs:
    def __init__(__self__, *,
                 name_label: pulumi.Input[str],
                 pool_id: pulumi.Input[str],
                 automatic: Optional[pulumi.Input[bool]] = None,
                 bond_mode: Optional[pulumi.Input[str]] = None,
                 default_is_locked: Optional[pulumi.Input[bool]] = None,
                 mtu: Optional[pulumi.Input[int]] = None,
                 name_description: Optional[pulumi.Input[str]] = None,
                 pif_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a XoaBondedNetwork resource.
        :param pulumi.Input[str] name_label: The name label of the network.
        :param pulumi.Input[str] pool_id: The pool id that this network should belong to.
        :param pulumi.Input[str] bond_mode: The bond mode that should be used for this network.
        :param pulumi.Input[bool] default_is_locked: This argument controls whether the network should enforce VIF locking. This defaults to `false` which means that no filtering rules are applied.
        :param pulumi.Input[int] mtu: The MTU of the network. Defaults to `1500` if unspecified.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] pif_ids: The pifs (uuid) that should be used for this network.
        """
        pulumi.set(__self__, "name_label", name_label)
        pulumi.set(__self__, "pool_id", pool_id)
        if automatic is not None:
            pulumi.set(__self__, "automatic", automatic)
        if bond_mode is not None:
            pulumi.set(__self__, "bond_mode", bond_mode)
        if default_is_locked is not None:
            pulumi.set(__self__, "default_is_locked", default_is_locked)
        if mtu is not None:
            pulumi.set(__self__, "mtu", mtu)
        if name_description is not None:
            pulumi.set(__self__, "name_description", name_description)
        if pif_ids is not None:
            pulumi.set(__self__, "pif_ids", pif_ids)

    @property
    @pulumi.getter(name="nameLabel")
    def name_label(self) -> pulumi.Input[str]:
        """
        The name label of the network.
        """
        return pulumi.get(self, "name_label")

    @name_label.setter
    def name_label(self, value: pulumi.Input[str]):
        pulumi.set(self, "name_label", value)

    @property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> pulumi.Input[str]:
        """
        The pool id that this network should belong to.
        """
        return pulumi.get(self, "pool_id")

    @pool_id.setter
    def pool_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "pool_id", value)

    @property
    @pulumi.getter
    def automatic(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "automatic")

    @automatic.setter
    def automatic(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "automatic", value)

    @property
    @pulumi.getter(name="bondMode")
    def bond_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The bond mode that should be used for this network.
        """
        return pulumi.get(self, "bond_mode")

    @bond_mode.setter
    def bond_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bond_mode", value)

    @property
    @pulumi.getter(name="defaultIsLocked")
    def default_is_locked(self) -> Optional[pulumi.Input[bool]]:
        """
        This argument controls whether the network should enforce VIF locking. This defaults to `false` which means that no filtering rules are applied.
        """
        return pulumi.get(self, "default_is_locked")

    @default_is_locked.setter
    def default_is_locked(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "default_is_locked", value)

    @property
    @pulumi.getter
    def mtu(self) -> Optional[pulumi.Input[int]]:
        """
        The MTU of the network. Defaults to `1500` if unspecified.
        """
        return pulumi.get(self, "mtu")

    @mtu.setter
    def mtu(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "mtu", value)

    @property
    @pulumi.getter(name="nameDescription")
    def name_description(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name_description")

    @name_description.setter
    def name_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name_description", value)

    @property
    @pulumi.getter(name="pifIds")
    def pif_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The pifs (uuid) that should be used for this network.
        """
        return pulumi.get(self, "pif_ids")

    @pif_ids.setter
    def pif_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "pif_ids", value)


@pulumi.input_type
class _XoaBondedNetworkState:
    def __init__(__self__, *,
                 automatic: Optional[pulumi.Input[bool]] = None,
                 bond_mode: Optional[pulumi.Input[str]] = None,
                 default_is_locked: Optional[pulumi.Input[bool]] = None,
                 mtu: Optional[pulumi.Input[int]] = None,
                 name_description: Optional[pulumi.Input[str]] = None,
                 name_label: Optional[pulumi.Input[str]] = None,
                 pif_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 pool_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering XoaBondedNetwork resources.
        :param pulumi.Input[str] bond_mode: The bond mode that should be used for this network.
        :param pulumi.Input[bool] default_is_locked: This argument controls whether the network should enforce VIF locking. This defaults to `false` which means that no filtering rules are applied.
        :param pulumi.Input[int] mtu: The MTU of the network. Defaults to `1500` if unspecified.
        :param pulumi.Input[str] name_label: The name label of the network.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] pif_ids: The pifs (uuid) that should be used for this network.
        :param pulumi.Input[str] pool_id: The pool id that this network should belong to.
        """
        if automatic is not None:
            pulumi.set(__self__, "automatic", automatic)
        if bond_mode is not None:
            pulumi.set(__self__, "bond_mode", bond_mode)
        if default_is_locked is not None:
            pulumi.set(__self__, "default_is_locked", default_is_locked)
        if mtu is not None:
            pulumi.set(__self__, "mtu", mtu)
        if name_description is not None:
            pulumi.set(__self__, "name_description", name_description)
        if name_label is not None:
            pulumi.set(__self__, "name_label", name_label)
        if pif_ids is not None:
            pulumi.set(__self__, "pif_ids", pif_ids)
        if pool_id is not None:
            pulumi.set(__self__, "pool_id", pool_id)

    @property
    @pulumi.getter
    def automatic(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "automatic")

    @automatic.setter
    def automatic(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "automatic", value)

    @property
    @pulumi.getter(name="bondMode")
    def bond_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The bond mode that should be used for this network.
        """
        return pulumi.get(self, "bond_mode")

    @bond_mode.setter
    def bond_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bond_mode", value)

    @property
    @pulumi.getter(name="defaultIsLocked")
    def default_is_locked(self) -> Optional[pulumi.Input[bool]]:
        """
        This argument controls whether the network should enforce VIF locking. This defaults to `false` which means that no filtering rules are applied.
        """
        return pulumi.get(self, "default_is_locked")

    @default_is_locked.setter
    def default_is_locked(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "default_is_locked", value)

    @property
    @pulumi.getter
    def mtu(self) -> Optional[pulumi.Input[int]]:
        """
        The MTU of the network. Defaults to `1500` if unspecified.
        """
        return pulumi.get(self, "mtu")

    @mtu.setter
    def mtu(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "mtu", value)

    @property
    @pulumi.getter(name="nameDescription")
    def name_description(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name_description")

    @name_description.setter
    def name_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name_description", value)

    @property
    @pulumi.getter(name="nameLabel")
    def name_label(self) -> Optional[pulumi.Input[str]]:
        """
        The name label of the network.
        """
        return pulumi.get(self, "name_label")

    @name_label.setter
    def name_label(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name_label", value)

    @property
    @pulumi.getter(name="pifIds")
    def pif_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The pifs (uuid) that should be used for this network.
        """
        return pulumi.get(self, "pif_ids")

    @pif_ids.setter
    def pif_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "pif_ids", value)

    @property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> Optional[pulumi.Input[str]]:
        """
        The pool id that this network should belong to.
        """
        return pulumi.get(self, "pool_id")

    @pool_id.setter
    def pool_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pool_id", value)


class XoaBondedNetwork(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 automatic: Optional[pulumi.Input[bool]] = None,
                 bond_mode: Optional[pulumi.Input[str]] = None,
                 default_is_locked: Optional[pulumi.Input[bool]] = None,
                 mtu: Optional[pulumi.Input[int]] = None,
                 name_description: Optional[pulumi.Input[str]] = None,
                 name_label: Optional[pulumi.Input[str]] = None,
                 pif_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 pool_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        A resource for managing Bonded Xen Orchestra networks. See the XCP-ng [networking docs](https://xcp-ng.org/docs/networking.html) for more details.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_xenorchestra as xenorchestra

        host1 = xenorchestra.get_xoa_host(name_label="Your host")
        eth1 = xenorchestra.get_xoa_pif(device="eth1",
            vlan=-1,
            host_id=host1.id)
        eth2 = xenorchestra.get_xoa_pif(device="eth2",
            vlan=-1,
            host_id=host1.id)
        # Create a bonded network from normal PIFs
        network = xenorchestra.XoaBondedNetwork("network",
            name_label="new network name",
            bond_mode="active-backup",
            pool_id=host1.pool_id,
            pif_ids=[
                eth1.id,
                eth2.id,
            ])
        # Create a bonded network from PIFs on VLANs
        eth1_vlan = xenorchestra.get_xoa_pif(device="eth1",
            vlan=15,
            host_id=host1.id)
        eth2_vlan = xenorchestra.get_xoa_pif(device="eth2",
            vlan=15,
            host_id=host1.id)
        # Create a bonded network from normal PIFs
        network_vlan = xenorchestra.XoaBondedNetwork("network_vlan",
            name_label="new network name",
            bond_mode="active-backup",
            pool_id=host1.pool_id,
            pif_ids=[
                eth1_vlan.id,
                eth2_vlan.id,
            ])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bond_mode: The bond mode that should be used for this network.
        :param pulumi.Input[bool] default_is_locked: This argument controls whether the network should enforce VIF locking. This defaults to `false` which means that no filtering rules are applied.
        :param pulumi.Input[int] mtu: The MTU of the network. Defaults to `1500` if unspecified.
        :param pulumi.Input[str] name_label: The name label of the network.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] pif_ids: The pifs (uuid) that should be used for this network.
        :param pulumi.Input[str] pool_id: The pool id that this network should belong to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: XoaBondedNetworkArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        A resource for managing Bonded Xen Orchestra networks. See the XCP-ng [networking docs](https://xcp-ng.org/docs/networking.html) for more details.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_xenorchestra as xenorchestra

        host1 = xenorchestra.get_xoa_host(name_label="Your host")
        eth1 = xenorchestra.get_xoa_pif(device="eth1",
            vlan=-1,
            host_id=host1.id)
        eth2 = xenorchestra.get_xoa_pif(device="eth2",
            vlan=-1,
            host_id=host1.id)
        # Create a bonded network from normal PIFs
        network = xenorchestra.XoaBondedNetwork("network",
            name_label="new network name",
            bond_mode="active-backup",
            pool_id=host1.pool_id,
            pif_ids=[
                eth1.id,
                eth2.id,
            ])
        # Create a bonded network from PIFs on VLANs
        eth1_vlan = xenorchestra.get_xoa_pif(device="eth1",
            vlan=15,
            host_id=host1.id)
        eth2_vlan = xenorchestra.get_xoa_pif(device="eth2",
            vlan=15,
            host_id=host1.id)
        # Create a bonded network from normal PIFs
        network_vlan = xenorchestra.XoaBondedNetwork("network_vlan",
            name_label="new network name",
            bond_mode="active-backup",
            pool_id=host1.pool_id,
            pif_ids=[
                eth1_vlan.id,
                eth2_vlan.id,
            ])
        ```

        :param str resource_name: The name of the resource.
        :param XoaBondedNetworkArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(XoaBondedNetworkArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 automatic: Optional[pulumi.Input[bool]] = None,
                 bond_mode: Optional[pulumi.Input[str]] = None,
                 default_is_locked: Optional[pulumi.Input[bool]] = None,
                 mtu: Optional[pulumi.Input[int]] = None,
                 name_description: Optional[pulumi.Input[str]] = None,
                 name_label: Optional[pulumi.Input[str]] = None,
                 pif_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 pool_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = XoaBondedNetworkArgs.__new__(XoaBondedNetworkArgs)

            __props__.__dict__["automatic"] = automatic
            __props__.__dict__["bond_mode"] = bond_mode
            __props__.__dict__["default_is_locked"] = default_is_locked
            __props__.__dict__["mtu"] = mtu
            __props__.__dict__["name_description"] = name_description
            if name_label is None and not opts.urn:
                raise TypeError("Missing required property 'name_label'")
            __props__.__dict__["name_label"] = name_label
            __props__.__dict__["pif_ids"] = pif_ids
            if pool_id is None and not opts.urn:
                raise TypeError("Missing required property 'pool_id'")
            __props__.__dict__["pool_id"] = pool_id
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="xenorchestra:index/bondedNetwork:BondedNetwork")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(XoaBondedNetwork, __self__).__init__(
            'xenorchestra:index/xoaBondedNetwork:XoaBondedNetwork',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            automatic: Optional[pulumi.Input[bool]] = None,
            bond_mode: Optional[pulumi.Input[str]] = None,
            default_is_locked: Optional[pulumi.Input[bool]] = None,
            mtu: Optional[pulumi.Input[int]] = None,
            name_description: Optional[pulumi.Input[str]] = None,
            name_label: Optional[pulumi.Input[str]] = None,
            pif_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            pool_id: Optional[pulumi.Input[str]] = None) -> 'XoaBondedNetwork':
        """
        Get an existing XoaBondedNetwork resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bond_mode: The bond mode that should be used for this network.
        :param pulumi.Input[bool] default_is_locked: This argument controls whether the network should enforce VIF locking. This defaults to `false` which means that no filtering rules are applied.
        :param pulumi.Input[int] mtu: The MTU of the network. Defaults to `1500` if unspecified.
        :param pulumi.Input[str] name_label: The name label of the network.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] pif_ids: The pifs (uuid) that should be used for this network.
        :param pulumi.Input[str] pool_id: The pool id that this network should belong to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _XoaBondedNetworkState.__new__(_XoaBondedNetworkState)

        __props__.__dict__["automatic"] = automatic
        __props__.__dict__["bond_mode"] = bond_mode
        __props__.__dict__["default_is_locked"] = default_is_locked
        __props__.__dict__["mtu"] = mtu
        __props__.__dict__["name_description"] = name_description
        __props__.__dict__["name_label"] = name_label
        __props__.__dict__["pif_ids"] = pif_ids
        __props__.__dict__["pool_id"] = pool_id
        return XoaBondedNetwork(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def automatic(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "automatic")

    @property
    @pulumi.getter(name="bondMode")
    def bond_mode(self) -> pulumi.Output[Optional[str]]:
        """
        The bond mode that should be used for this network.
        """
        return pulumi.get(self, "bond_mode")

    @property
    @pulumi.getter(name="defaultIsLocked")
    def default_is_locked(self) -> pulumi.Output[Optional[bool]]:
        """
        This argument controls whether the network should enforce VIF locking. This defaults to `false` which means that no filtering rules are applied.
        """
        return pulumi.get(self, "default_is_locked")

    @property
    @pulumi.getter
    def mtu(self) -> pulumi.Output[Optional[int]]:
        """
        The MTU of the network. Defaults to `1500` if unspecified.
        """
        return pulumi.get(self, "mtu")

    @property
    @pulumi.getter(name="nameDescription")
    def name_description(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "name_description")

    @property
    @pulumi.getter(name="nameLabel")
    def name_label(self) -> pulumi.Output[str]:
        """
        The name label of the network.
        """
        return pulumi.get(self, "name_label")

    @property
    @pulumi.getter(name="pifIds")
    def pif_ids(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The pifs (uuid) that should be used for this network.
        """
        return pulumi.get(self, "pif_ids")

    @property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> pulumi.Output[str]:
        """
        The pool id that this network should belong to.
        """
        return pulumi.get(self, "pool_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'ResourceSetLimitArgs',
    'ResourceSetLimitArgsDict',
    'VmCdromArgs',
    'VmCdromArgsDict',
    'VmDiskArgs',
    'VmDiskArgsDict',
    'VmNetworkArgs',
    'VmNetworkArgsDict',
]

MYPY = False

if not MYPY:
    class ResourceSetLimitArgsDict(TypedDict):
        quantity: pulumi.Input[int]
        """
        The numerical limit for the given type.
        """
        type: pulumi.Input[str]
        """
        The type of resource set limit. Must be cpus, memory or disk.
        """
elif False:
    ResourceSetLimitArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ResourceSetLimitArgs:
    def __init__(__self__, *,
                 quantity: pulumi.Input[int],
                 type: pulumi.Input[str]):
        """
        :param pulumi.Input[int] quantity: The numerical limit for the given type.
        :param pulumi.Input[str] type: The type of resource set limit. Must be cpus, memory or disk.
        """
        pulumi.set(__self__, "quantity", quantity)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def quantity(self) -> pulumi.Input[int]:
        """
        The numerical limit for the given type.
        """
        return pulumi.get(self, "quantity")

    @quantity.setter
    def quantity(self, value: pulumi.Input[int]):
        pulumi.set(self, "quantity", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        The type of resource set limit. Must be cpus, memory or disk.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)


if not MYPY:
    class VmCdromArgsDict(TypedDict):
        id: pulumi.Input[str]
        """
        The ID of the ISO (VDI) to attach to the VM. This can be easily provided by using the `vdi` data source.
        """
elif False:
    VmCdromArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class VmCdromArgs:
    def __init__(__self__, *,
                 id: pulumi.Input[str]):
        """
        :param pulumi.Input[str] id: The ID of the ISO (VDI) to attach to the VM. This can be easily provided by using the `vdi` data source.
        """
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        """
        The ID of the ISO (VDI) to attach to the VM. This can be easily provided by using the `vdi` data source.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)


if not MYPY:
    class VmDiskArgsDict(TypedDict):
        name_label: pulumi.Input[str]
        """
        The name for the disk
        """
        size: pulumi.Input[int]
        """
        The size in bytes for the disk.
        """
        sr_id: pulumi.Input[str]
        """
        The storage repository ID to use.
        """
        attached: NotRequired[pulumi.Input[bool]]
        """
        Whether the device should be attached to the VM.
        """
        name_description: NotRequired[pulumi.Input[str]]
        """
        The description for the disk
        """
        position: NotRequired[pulumi.Input[str]]
        """
        Indicates the order of the block device.
        """
        vbd_id: NotRequired[pulumi.Input[str]]
        vdi_id: NotRequired[pulumi.Input[str]]
elif False:
    VmDiskArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class VmDiskArgs:
    def __init__(__self__, *,
                 name_label: pulumi.Input[str],
                 size: pulumi.Input[int],
                 sr_id: pulumi.Input[str],
                 attached: Optional[pulumi.Input[bool]] = None,
                 name_description: Optional[pulumi.Input[str]] = None,
                 position: Optional[pulumi.Input[str]] = None,
                 vbd_id: Optional[pulumi.Input[str]] = None,
                 vdi_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] name_label: The name for the disk
        :param pulumi.Input[int] size: The size in bytes for the disk.
        :param pulumi.Input[str] sr_id: The storage repository ID to use.
        :param pulumi.Input[bool] attached: Whether the device should be attached to the VM.
        :param pulumi.Input[str] name_description: The description for the disk
        :param pulumi.Input[str] position: Indicates the order of the block device.
        """
        pulumi.set(__self__, "name_label", name_label)
        pulumi.set(__self__, "size", size)
        pulumi.set(__self__, "sr_id", sr_id)
        if attached is not None:
            pulumi.set(__self__, "attached", attached)
        if name_description is not None:
            pulumi.set(__self__, "name_description", name_description)
        if position is not None:
            pulumi.set(__self__, "position", position)
        if vbd_id is not None:
            pulumi.set(__self__, "vbd_id", vbd_id)
        if vdi_id is not None:
            pulumi.set(__self__, "vdi_id", vdi_id)

    @property
    @pulumi.getter(name="nameLabel")
    def name_label(self) -> pulumi.Input[str]:
        """
        The name for the disk
        """
        return pulumi.get(self, "name_label")

    @name_label.setter
    def name_label(self, value: pulumi.Input[str]):
        pulumi.set(self, "name_label", value)

    @property
    @pulumi.getter
    def size(self) -> pulumi.Input[int]:
        """
        The size in bytes for the disk.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: pulumi.Input[int]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter(name="srId")
    def sr_id(self) -> pulumi.Input[str]:
        """
        The storage repository ID to use.
        """
        return pulumi.get(self, "sr_id")

    @sr_id.setter
    def sr_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "sr_id", value)

    @property
    @pulumi.getter
    def attached(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the device should be attached to the VM.
        """
        return pulumi.get(self, "attached")

    @attached.setter
    def attached(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "attached", value)

    @property
    @pulumi.getter(name="nameDescription")
    def name_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description for the disk
        """
        return pulumi.get(self, "name_description")

    @name_description.setter
    def name_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name_description", value)

    @property
    @pulumi.getter
    def position(self) -> Optional[pulumi.Input[str]]:
        """
        Indicates the order of the block device.
        """
        return pulumi.get(self, "position")

    @position.setter
    def position(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "position", value)

    @property
    @pulumi.getter(name="vbdId")
    def vbd_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "vbd_id")

    @vbd_id.setter
    def vbd_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vbd_id", value)

    @property
    @pulumi.getter(name="vdiId")
    def vdi_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "vdi_id")

    @vdi_id.setter
    def vdi_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vdi_id", value)


if not MYPY:
    class VmNetworkArgsDict(TypedDict):
        network_id: pulumi.Input[str]
        """
        The ID of the network the VM will be on.
        """
        attached: NotRequired[pulumi.Input[bool]]
        """
        Whether the device should be attached to the VM.
        """
        device: NotRequired[pulumi.Input[str]]
        expected_ip_cidr: NotRequired[pulumi.Input[str]]
        ipv4_addresses: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        ipv6_addresses: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        mac_address: NotRequired[pulumi.Input[str]]
elif False:
    VmNetworkArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class VmNetworkArgs:
    def __init__(__self__, *,
                 network_id: pulumi.Input[str],
                 attached: Optional[pulumi.Input[bool]] = None,
                 device: Optional[pulumi.Input[str]] = None,
                 expected_ip_cidr: Optional[pulumi.Input[str]] = None,
                 ipv4_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 ipv6_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 mac_address: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] network_id: The ID of the network the VM will be on.
        :param pulumi.Input[bool] attached: Whether the device should be attached to the VM.
        """
        pulumi.set(__self__, "network_id", network_id)
        if attached is not None:
            pulumi.set(__self__, "attached", attached)
        if device is not None:
            pulumi.set(__self__, "device", device)
        if expected_ip_cidr is not None:
            pulumi.set(__self__, "expected_ip_cidr", expected_ip_cidr)
        if ipv4_addresses is not None:
            pulumi.set(__self__, "ipv4_addresses", ipv4_addresses)
        if ipv6_addresses is not None:
            pulumi.set(__self__, "ipv6_addresses", ipv6_addresses)
        if mac_address is not None:
            pulumi.set(__self__, "mac_address", mac_address)

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> pulumi.Input[str]:
        """
        The ID of the network the VM will be on.
        """
        return pulumi.get(self, "network_id")

    @network_id.setter
    def network_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "network_id", value)

    @property
    @pulumi.getter
    def attached(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the device should be attached to the VM.
        """
        return pulumi.get(self, "attached")

    @attached.setter
    def attached(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "attached", value)

    @property
    @pulumi.getter
    def device(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "device")

    @device.setter
    def device(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "device", value)

    @property
    @pulumi.getter(name="expectedIpCidr")
    def expected_ip_cidr(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "expected_ip_cidr")

    @expected_ip_cidr.setter
    def expected_ip_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "expected_ip_cidr", value)

    @property
    @pulumi.getter(name="ipv4Addresses")
    def ipv4_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "ipv4_addresses")

    @ipv4_addresses.setter
    def ipv4_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "ipv4_addresses", value)

    @property
    @pulumi.getter(name="ipv6Addresses")
    def ipv6_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "ipv6_addresses")

    @ipv6_addresses.setter
    def ipv6_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "ipv6_addresses", value)

    @property
    @pulumi.getter(name="macAddress")
    def mac_address(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "mac_address")

    @mac_address.setter
    def mac_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mac_address", value)


